diff mbox series

[11/37] qapi/common.py: Replace one-letter 'c' variable

Message ID 20200915224027.2529813-12-jsnow@redhat.com
State New
Headers show
Series qapi: static typing conversion, pt1 | expand

Commit Message

John Snow Sept. 15, 2020, 10:40 p.m. UTC
Signed-off-by: John Snow <jsnow@redhat.com>
---
 scripts/qapi/common.py | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

Comments

Markus Armbruster Sept. 17, 2020, 2:17 p.m. UTC | #1
John Snow <jsnow@redhat.com> writes:

> Signed-off-by: John Snow <jsnow@redhat.com>

> ---

>  scripts/qapi/common.py | 8 ++++----

>  1 file changed, 4 insertions(+), 4 deletions(-)

>

> diff --git a/scripts/qapi/common.py b/scripts/qapi/common.py

> index c665e67495..4c079755d3 100644

> --- a/scripts/qapi/common.py

> +++ b/scripts/qapi/common.py

> @@ -30,14 +30,14 @@ def camel_to_upper(value):

>      new_name = ''

>      length = len(c_fun_str)

>      for i in range(length):

> -        c = c_fun_str[i]

> -        # When c is upper and no '_' appears before, do more checks

> -        if c.isupper() and (i > 0) and c_fun_str[i - 1] != '_':

> +        char = c_fun_str[i]

> +        # When char is upper and no '_' appears before, do more checks


Good opportunity to tweak the language: "When char is upper case".

> +        if char.isupper() and (i > 0) and c_fun_str[i - 1] != '_':

>              if i < length - 1 and c_fun_str[i + 1].islower():

>                  new_name += '_'

>              elif c_fun_str[i - 1].isdigit():

>                  new_name += '_'

> -        new_name += c

> +        new_name += char

>      return new_name.lstrip('_').upper()
John Snow Sept. 17, 2020, 5:51 p.m. UTC | #2
On 9/17/20 10:17 AM, Markus Armbruster wrote:
> John Snow <jsnow@redhat.com> writes:

> 

>> Signed-off-by: John Snow <jsnow@redhat.com>

>> ---

>>   scripts/qapi/common.py | 8 ++++----

>>   1 file changed, 4 insertions(+), 4 deletions(-)

>>

>> diff --git a/scripts/qapi/common.py b/scripts/qapi/common.py

>> index c665e67495..4c079755d3 100644

>> --- a/scripts/qapi/common.py

>> +++ b/scripts/qapi/common.py

>> @@ -30,14 +30,14 @@ def camel_to_upper(value):

>>       new_name = ''

>>       length = len(c_fun_str)

>>       for i in range(length):

>> -        c = c_fun_str[i]

>> -        # When c is upper and no '_' appears before, do more checks

>> -        if c.isupper() and (i > 0) and c_fun_str[i - 1] != '_':

>> +        char = c_fun_str[i]

>> +        # When char is upper and no '_' appears before, do more checks

> 

> Good opportunity to tweak the language: "When char is upper case".

> 


ACK, change made.
diff mbox series

Patch

diff --git a/scripts/qapi/common.py b/scripts/qapi/common.py
index c665e67495..4c079755d3 100644
--- a/scripts/qapi/common.py
+++ b/scripts/qapi/common.py
@@ -30,14 +30,14 @@  def camel_to_upper(value):
     new_name = ''
     length = len(c_fun_str)
     for i in range(length):
-        c = c_fun_str[i]
-        # When c is upper and no '_' appears before, do more checks
-        if c.isupper() and (i > 0) and c_fun_str[i - 1] != '_':
+        char = c_fun_str[i]
+        # When char is upper and no '_' appears before, do more checks
+        if char.isupper() and (i > 0) and c_fun_str[i - 1] != '_':
             if i < length - 1 and c_fun_str[i + 1].islower():
                 new_name += '_'
             elif c_fun_str[i - 1].isdigit():
                 new_name += '_'
-        new_name += c
+        new_name += char
     return new_name.lstrip('_').upper()